..
      Copyright 2018 Catalyst IT Ltd
      All Rights Reserved.
      not use this file except in compliance with the License. You may obtain
      a copy of the License at

          http://www.apache.org/licenses/LICENSE-2.0

      Unless required by applicable law or agreed to in writing, software
      distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
      WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
      License for the specific language governing permissions and limitations
      under the License.

Qinling Videos
==============

This page contains Qinling related videos including the OpenStack Summit
presentations, the project introduction, etc.

* 2017.10,
  `Qinling introduction demo <https://youtu.be/K2SiMZllN_A>`_
* 2017.11, OpenStack Sydney Summit,
  `Make your application "serverless" <https://www.openstack.org/videos/sydney-2017/make-your-application-serverless>`_
* 2018.05, OpenStack Vancouver Summit,
  `How to implement FaaS in openstack <https://www.openstack.org/videos/vancouver-2018/how-to-implement-faas-in-openstack-for-public-cloud>`_
* 2018.05, OpenStack Vancouver Summit,
  `Qinling project update <https://www.openstack.org/videos/vancouver-2018/qinling-project-update>`_
